static char *cpyrgt =
"@(#)zapmailhead.c Copyright (c) Leif Erlingsson 93-08-07, 96-06-06, 96-07-18, 97-02-12, 97-10-27";


/*	TO GENERATE zapmailhead-terse, 	EDIT ABOVE COPYRIGHT NOTICE	*/
/*	TO zapmailhead-terse.c AND UNCOMMENT THE FOLLOWING LINE:	*/
/*	#define terse							*/
/*	THEN SAVE THIS FILE AS zapmailhead-terse.c			*/


/*	Usage:	zapmailhead input output	or			*/
/*		zapmailhead input (stdout)	or			*/
/*		zapmailhead (stdin) (stdout)				*/

/*	Examples:							*/
/*	zapmailhead mailarch /tmp/x; pine -f /tmp/x			*/
/*	zapmailhead mailarch | less					*/
/*	gzip -d -c mailarch.gz | zapmailhead > /tmp/x; pine -f /tmp/x	*/
/*									*/
/*	#!/bin/sh							*/
/*	#								*/
/*	# cleanhed			Clean mail headers		*/
/*	#								*/
/*	ORGMAIL=/var/spool/mail/$LOGNAME				*/
/*	lockfile -l3600 -ml						*/
/*	zapmailhead $ORGMAIL > /tmp/cleanhed.$LOGNAME.$$		*/
/*	cp /tmp/cleanhed.$LOGNAME.$$ $ORGMAIL				*/
/*	rm -f /tmp/cleanhed.$LOGNAME.$$					*/
/*	lockfile -mu							*/
/*									*/

/*									*/
/*	REVISION HISTORY:						*/
/*									*/
/*	96-06-06    Leif Erlingsson	Added MIME support ---		*/
/*					no longer removes		*/
/*					MIME 1.0 headers.		*/
/*									*/
/*	96-07-18    Leif Erlingsson	Also preserves Status:		*/
/*									*/
/*	96-12-02    Leif Erlingsson	Also preserves cc: (lower case)	*/
/*									*/
/*	97-02-12    Leif Erlingsson	Ignore all case replacing	*/
/*					strncmp calls with strncasecmp.	*/
/*					First `From ' case sensitive!	*/
/*									*/
/*					Preserve continuation lines of	*/
/*					e.g. Cc: lists if e.g. the Cc:	*/
/*					header was preserved in the	*/
/*					first place.			*/
/*									*/
/*	97-10-27    Leif Erlingsson	Also preserves Bcc:		*/
/*					Also preserves Comment:		*/
/*									*/



#include <stdio.h>


main(argc, argv)
int argc;
char *argv[];
{
   FILE *fp_in, *fp_out, *fopen();

   char *prog = argv[0];		/* program name for errors	*/

   int v;				/* simulate void type-cast	*/
   int m = -1;				/* not mail header is default	*/
   int e = 0;				/* zero when last line empty	*/
   int keep = 0;			/* when not zero, keep line	*/
   int oldkeep = 0;			/* previous value of keep	*/

   char line[BUFSIZ];			/* long enough?			*/
   int len;				/* line length			*/
   char *p;

   /* Keep in mail header:						*/

   char *From = "From ";
   char *Subject = "Subject: ";
   
#ifndef terse
   char *FromI = "From: ";
   char *Date = "Date: ";
   char *To = "To: ";
   char *Cc = "Cc: ";
   char *Bcc = "Bcc: ";
   char *X_To = "X-To: ";
   char *X_Cc = "X-Cc: ";
   char *X_Bcc = "X-Bcc: ";
   char *Status = "Status: ";
   char *Comment = "Comment: ";
   char *Comments = "Comments: ";
#endif

   char *Newsgroups = "Newsgroups: ";
   char *Distribution = "Distribution: ";
   char *Summary = "Summary: ";
   char *Keywords = "Keywords: ";
   char *MIMEVersion = "MIME-Version: ";
   char *MimeVersion = "Mime-Version: ";
   char *ContentType = "Content-Type: ";
   char *ContentTransferEncoding = "Content-Transfer-Encoding: ";

   /* Continuation lines, first character:				*/

   char *Space = " ";
   char *Tab = "	";

   char *s;

   fp_in = stdin;
   fp_out = stdout;

   if (argc > 3)			/* more than 2 parameters	*/
      {
      v = fprintf(stderr,
         "%s: too many arguments\n", prog);
      exit(1);
      }

   if (argc > 1)			/* more than 0 parameters	*/
      {
      if ((fp_in = fopen(*++argv, "r")) == NULL)
	 {
         v = fprintf(stderr,
            "%s: can't open %s\n", prog, *argv);
         exit(1);
	 }
      }

   if (argc > 2)			/* more than 1 parameter	*/
      {
      if ((fp_out = fopen(*++argv, "w")) == NULL)
	 {
         v = fprintf(stderr,
            "%s: can't open %s\n", prog, *argv);
         exit(1);
	 }
      }

   while (fgets (line, BUFSIZ, fp_in) != NULL)
      {
      p = line;
      len = strlen (p);
      s = p + len - 1; if (*s == '\n') { *s == '\0'; len = len -1; }

      s = From;				/* check for mail header (From)	*/
      if (len)
         {
         if (m && !e && !strncmp (s, p, strlen (s)))
            {
            m = 0;			/* YEA!	mail header begins here	*/
            }
         }
      else
         {
         m = -1;			/* mail header ended here	*/
					/* or earlier			*/
         }

      if (!m)
         {
         /* this is a mail header */
         oldkeep = keep; keep = 0;	/* default is zap line		*/
         if (oldkeep) {
            s = Space;
            if (!strncasecmp (s, p, 1)) { keep = -1; }		/* keep */
            s = Tab;
            if (!strncasecmp (s, p, 1)) { keep = -1; }		/* keep */
         }
         s = From;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Subject;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
#ifndef terse
         s = FromI;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Date;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = To;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Cc;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Bcc;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = X_To;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = X_Cc;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = X_Bcc;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Status;	/* Added 18 Jul 1996 by Leif Erlingsson		*/
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Comment;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Comments;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
#endif
         s = Newsgroups;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Distribution;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Summary;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = Keywords;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/

         /* Added MIME support  6 Jun 1996 by Leif Erlingsson		*/
         s = MIMEVersion;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = MimeVersion;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = ContentType;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/
         s = ContentTransferEncoding;
         if (!strncasecmp (s, p, strlen (s))) { keep = -1; }	/* keep	*/

         }
      else
         {
         keep = -1;			/* default is keep line		*/
         /* code can be placed here to delete lines in mail body	*/
         /* such code should set keep = 0 for lines to be deleted	*/
         }

      if (keep)
         {
         fputs (line, fp_out);
         }

      e = ( len ? -1 : 0 );		/* zero when line empty else -1	*/
      }
   
   if (ferror(stdout))
      {
      v = fprintf(stderr, "%s: error writing stdout\n", prog);
      exit(2);
      }

   exit(0);
}
